#!/usr/bin/python

import socket
import pygame
import sys

ROVER_CONTROL_IP = '192.168.99.1'
ROVER_CONTROL_PORT = 10001

# UDP_send_data(data,ip,port)
def UDP_send_data(data,ip,port): 
    error_code = 0
    UDP_socket = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
    UDP_socket.sendto(data,(ip,port))
    return error_code

# data_to_pwm(axis_1,axis_2)
def data_to_pwm(axis_1,axis_2):
    deviation = 0.01
    LF,LR,RL,RR = 0,0,0,0
    if axis_1 < 0:
        LF = abs(int (axis_1 * 100))
    elif axis_1 > 0:
        LR = abs(int ((axis_1 + deviation ) * 100))
    if axis_2 < 0:
        RL = abs(int (axis_2 * 100))
    elif axis_2 > 0:
        RR = abs(int ((axis_2 + deviation) * 100))
    return (LF,LR,RL,RR)

# start joystick control client
def start_control_client(device_id,robot_ip,robot_port):      
    print("[MSG]> start_control_client()")
    
    # init joystick values
    interference_level = 99
    LF,LR,RL,RR = 0,0,0,0    
    
    #init pygame 
    pygame.init()
    pygame.joystick.init()
    clock = pygame.time.Clock()
    
    #init joystick    
    try:
        j = pygame.joystick.Joystick(device_id) # create a joystick instance
        j.init() # init instance
        print '[MSG]> Enabled joystick: ' + j.get_name()
    except pygame.error:
        print '[MSG]> no joystick found.'

    while True:
        # get joystick values
        for e in pygame.event.get():    
            control_msg = ""
            left_j_value = 0
            right_j_value = 0                   
            left_j_value = j.get_axis(1)
            right_j_value = j.get_axis(2)       
            #format control message from joystick values
            if (left_j_value or right_j_value):
                LF,LR,RL,RR=0,0,0,0
                LF,LR,RL,RR = data_to_pwm(left_j_value,right_j_value)  
                if LF < interference_level: LF=0
                if LR < interference_level: LR=0
                if RL < interference_level: RL=0
                if RR < interference_level: RR=0            
                control_msg = '{},{},{},{}'.format(LF,LR,RL,RR)       
            # send control message to server
            if control_msg != "": 
                print "[JOY]> {0}".format(control_msg)
                UDP_send_data(control_msg,robot_ip, robot_port)

        clock.tick(100) 
        
# main
if __name__ == "__main__":
    try:
        start_control_client(0,ROVER_CONTROL_IP,ROVER_CONTROL_PORT)
    finally:
        print("[MSG]> Exit")
        sys.exit()
